package wm.api.demo;

import wm.api.general._WM_GENERAL;
import wm.rfid.api.demo.R;
import android.app.Activity;
import android.content.Context;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.CheckBox;
import android.widget.Spinner;

public class SettingsGeneral extends Activity {

	
	private _WM_GENERAL general = null;
	
	private Context mContext = null;
	
	private Button 	mBtnReset, mBtnPowerMode, mBtnSoundMode, mBtnDisplayData, mBtnBarcodeScanButton, mBtnRFIDScanButton;
	private Spinner mSpinPowerMode, mSpinSoundMode;
	
	private CheckBox mCbDisplayData, mCbBarcodeScanButton, mCbRFIDScanButton;
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.settings_general);
		setTitle("General API Demo");
		mContext = this;
		
		Initialize();
	}
	
	private void Initialize() {

		general = new _WM_GENERAL();
		
		InitView();
		InitSpinPowerMode();
		InitSpinSoundMode();
	}
	
	private void InitView() {
		mBtnReset		= (Button) findViewById(R.id.button_reset);
		mBtnPowerMode	= (Button) findViewById(R.id.button_power_saving);
		mBtnSoundMode 	= (Button) findViewById(R.id.button_sound_mode);
		mBtnDisplayData 	= (Button) findViewById(R.id.button_display_data);
		mBtnBarcodeScanButton	= (Button) findViewById(R.id.button_disable_barcode_scan_button);
		mBtnRFIDScanButton		= (Button) findViewById(R.id.button_disable_rfid_scan_button);
		
		mSpinPowerMode 	= (Spinner) findViewById(R.id.spin_power_saving);
		mSpinSoundMode 	= (Spinner) findViewById(R.id.spin_sound_mode);
		
		mCbDisplayData	= (CheckBox) findViewById(R.id.cb_display_data);
		mCbBarcodeScanButton	= (CheckBox) findViewById(R.id.cb_disable_barcode_scan_button);
		mCbRFIDScanButton		= (CheckBox) findViewById(R.id.cb_disable_rfid_scan_button);
		
		mBtnReset.setOnClickListener(Click_Reset);
		mBtnPowerMode.setOnClickListener(Click_Power_Mode);
		mBtnSoundMode.setOnClickListener(Click_Sound_Mode);
		mBtnDisplayData.setOnClickListener(Click_Display_Data);
		mBtnBarcodeScanButton.setOnClickListener(Click_Barcode_Scan_Button);
		mBtnRFIDScanButton.setOnClickListener(Click_RFID_Scan_Button);
	}

	private OnClickListener Click_Reset = new OnClickListener() {
		public void onClick(View v) {
			reset();
		}
	};
	private OnClickListener Click_Power_Mode = new OnClickListener() {
		public void onClick(View v) {
			set_power_mode();
		}
	};
	private OnClickListener Click_Sound_Mode = new OnClickListener() {
		public void onClick(View v) {
			set_sound_mode();
		}
	};
	private OnClickListener Click_Display_Data = new OnClickListener() {
		public void onClick(View v) {
			set_display_data(mCbDisplayData.isChecked());
		}
	};
	private OnClickListener Click_Barcode_Scan_Button = new OnClickListener() {
		public void onClick(View v) {
			set_barcode_scan_button(mCbBarcodeScanButton.isChecked());
		}
	};
	private OnClickListener Click_RFID_Scan_Button = new OnClickListener() {
		public void onClick(View v) {
			set_rfid_scan_button(mCbRFIDScanButton.isChecked());
		}
	};
	
	private void InitSpinPowerMode() {	
		ArrayAdapter<_WM_GENERAL.PowerSaving> adapter = new ArrayAdapter<_WM_GENERAL.PowerSaving>(this, android.R.layout.simple_spinner_item, _WM_GENERAL.PowerSaving.values());
		adapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
		mSpinPowerMode.setAdapter(adapter);
		mSpinPowerMode.setSelection(0);
	}
	
	private void InitSpinSoundMode() {	
		ArrayAdapter<_WM_GENERAL.SoundMode> adapter = new ArrayAdapter<_WM_GENERAL.SoundMode>(this, android.R.layout.simple_spinner_item, _WM_GENERAL.SoundMode.values());
		adapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
		mSpinSoundMode.setAdapter(adapter);
		mSpinSoundMode.setSelection(0);
	}
	

	/****************************************************************************************
	 * WDC Reset
	 **************************************************************************************/
	private void reset(){
		general.Reset(mContext);
	}
	
	/****************************************************************************************
	 * 	_WM_GENERAL API:
	 * 
	 * 	public static enum PowerSaving {
	 *		Minute_1,
	 *		Minute_5, 
	 *		Minute_10,
	 *		None
	 *	}
	 * 
	 * Power Saving Mode:
	 * 	1. _WM_GENERAL.PowerSaving.Minute_1
	 * 	2. _WM_GENERAL.PowerSaving.Minute_5
	 * 	3. _WM_GENERAL.PowerSaving.Minute_10
	 * 	4. _WM_GENERAL.PowerSaving.None
	 *  
	 **************************************************************************************/
	private void set_power_mode() {
		int mode = mSpinPowerMode.getSelectedItemPosition();
		Log.i("_WM_", "set_power_mode = " + mode);
		general.SetPowerSaving(mContext, _WM_GENERAL.PowerSaving.values()[mode]);
	}
	
	/****************************************************************************************
	 * 	_WM_GENERAL API:
	 * 
	 * 	public static enum SoundMode {
	 *		Sound_Vibration,
	 *		Sound, 
	 *		Vibration,
	 *		None
	 *	}
	 * 
	 * Sound Mode:
	 * 	1. _WM_GENERAL.SoundMode.Sound_Vibration
	 * 	2. _WM_GENERAL.SoundMode.Sound
	 * 	3. _WM_GENERAL.SoundMode.Vibration
	 * 	4. _WM_GENERAL.SoundMode.None
	 * 
	 **************************************************************************************/
	private void set_sound_mode() {
		int mode = mSpinSoundMode.getSelectedItemPosition();
		Log.i("_WM_", "set_sound_mode = " + mode);
		general.SetSoundMode(mContext, _WM_GENERAL.SoundMode.values()[mode]);		
	}
	
	/****************************************************************************************
	 * 	_WM_GENERAL API:
	 * 
	 * Display data on UI:
	 * 	
	 * 	isDisplay	true : display data on UI
	 *				false: doesnt display data on UI.
	 * 
	 **************************************************************************************/
	private void set_display_data(boolean isDisplay) {
		_WM_GENERAL general = new _WM_GENERAL();
		general.SetDisplayData(mContext, isDisplay);
	}
	
	/****************************************************************************************
	 * 	_WM_GENERAL API:
	 * 
	 * Barcode Scan Button:
	 * 	
	 * 	isDisable	true : disable barcode scan button
	 *				false: enable barcode scan button.
	 * 
	 **************************************************************************************/
	private void set_barcode_scan_button(boolean isDisable) {
		_WM_GENERAL general = new _WM_GENERAL();
		general.SetBarcodeScanButton(mContext, isDisable);
	}
	
	/****************************************************************************************
	 * 	_WM_GENERAL API:
	 * 
	 * RFID Scan Button:
	 * 	
	 * 	isDisable	true : disable rfid scan button
	 *				false: enable rfid scan button.
	 * 
	 **************************************************************************************/
	private void set_rfid_scan_button(boolean isDisable) {
		_WM_GENERAL general = new _WM_GENERAL();
		general.SetRFIDScanButton(mContext, isDisable);
	}

}
