package wm.api.demo;

import wm.api.rfid._WM_RFID;
import wm.rfid.api.demo.R;
import android.app.Activity;
import android.content.Context;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Spinner;

public class SettingsUHFRFID extends Activity {
	
	
	private _WM_RFID rfid = null;
	
	private Context mContext = null;

	private Button mBtnClean, mBtnReadTag, mBtnWriteTag, mBtnTriggerMode;
	private EditText mSetWriteData, mResult;
	private Spinner mSpinReadArea, mSpinWriteArea, mSpinTriggerMode, mSpinTriggerTime;
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.settings_uhf_rfid);
		setTitle("RFID API Demo");
		mContext = this;

		Initialize();
	}
	
	private void Initialize() {
		
		rfid = new _WM_RFID();
		
		InitView();
		InitSpinReadTag();
		InitSpinWriteTag();
		InitSpinTriggerMode();
		InitSpinTriggerTime();
	}
	
	private void InitView() {
		
		mBtnClean		= (Button) findViewById(R.id.button_clean);
		mBtnReadTag	 	= (Button) findViewById(R.id.button_read_tag);
		mBtnWriteTag 	= (Button) findViewById(R.id.button_write_tag);
		mBtnTriggerMode = (Button) findViewById(R.id.button_trigger_mode);
		
		mResult 		= (EditText) findViewById(R.id.edit_result);
		mSetWriteData 	= (EditText) findViewById(R.id.edit_set_write_data);
		
		mSpinReadArea 	= (Spinner) findViewById(R.id.spin_read_tag);
		mSpinWriteArea 	= (Spinner) findViewById(R.id.spin_write_tag);
		mSpinTriggerMode= (Spinner) findViewById(R.id.spin_trigger_mode);
		mSpinTriggerTime= (Spinner) findViewById(R.id.spin_trigger_time);
		
		mBtnClean.setOnClickListener(Click_Clean);
		mBtnReadTag.setOnClickListener(Click_Read_Tag);
		mBtnWriteTag.setOnClickListener(Click_Write_Tag);
		mBtnTriggerMode.setOnClickListener(Click_Trigger_Mode);
	}

	private OnClickListener Click_Clean = new OnClickListener() {
		public void onClick(View v) {
			mResult.setText("");
		}
	};
	private OnClickListener Click_Read_Tag = new OnClickListener() {
		public void onClick(View v) {
			read_tag();
		}
	};
	private OnClickListener Click_Write_Tag = new OnClickListener() {
		public void onClick(View v) {
			write_tag();
		}
	};
	private OnClickListener Click_Trigger_Mode = new OnClickListener() {
		public void onClick(View v) {
			set_trigger_mode();
		}
	};
	
	private void InitSpinReadTag() {	
		CharSequence[] seq = new CharSequence[]{"Password", "EPC", "TID", "User"};
		ArrayAdapter<CharSequence> adapter = new ArrayAdapter<CharSequence>(this, android.R.layout.simple_spinner_item, seq);
		adapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
		mSpinReadArea.setAdapter(adapter);
		mSpinReadArea.setSelection(0);
	}
	private void InitSpinWriteTag() {	
		CharSequence[] seq = new CharSequence[]{"Password", "EPC", "User"};
		ArrayAdapter<CharSequence> adapter = new ArrayAdapter<CharSequence>(this, android.R.layout.simple_spinner_item, seq);
		adapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
		mSpinWriteArea.setAdapter(adapter);
		mSpinWriteArea.setSelection(0);
	}
	private void InitSpinTriggerMode() {	
		ArrayAdapter<_WM_RFID.TriggerMode> adapter = new ArrayAdapter<_WM_RFID.TriggerMode>(this, android.R.layout.simple_spinner_item, _WM_RFID.TriggerMode.values());
		adapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
		mSpinTriggerMode.setAdapter(adapter);
		mSpinTriggerMode.setSelection(0);
	}
	private void InitSpinTriggerTime() {	
		ArrayAdapter<_WM_RFID.TriggerTime> adapter = new ArrayAdapter<_WM_RFID.TriggerTime>(this, android.R.layout.simple_spinner_item, _WM_RFID.TriggerTime.values());
		adapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
		mSpinTriggerTime.setAdapter(adapter);
		mSpinTriggerTime.setSelection(0);
	}
	//---------------------------------------------------------------------------------------------------------------------------
	
	/****************************************************************************************
	 * UHF-RFID Read tag
	 *
	 * Area 0 is Password
	 * Area 1 is EPC
	 * Area 2 is TID
	 * Area 3 is User
	 ****************************************************************************************/
	private void read_tag() {
		int ReadArea = mSpinReadArea.getSelectedItemPosition(); //select read tag area
		Log.i("_WM_", "select read tag - area = " + ReadArea);
		rfid.UHF_Read(mContext, ReadArea);
	}
	
	/****************************************************************************************
	 * UHF-RFID Read tag
	 *
	 * Area 0 is Password
	 * Area 1 is EPC
	 * Area 2 is User
	 * 
	 * Area Password WriteData is 8 bytes 
	 * Area EPC WriteData is 12 bytes
	 * Area User WriteData is 64 bytes
	 * and those are composed by "0, 1, 2, 3, 4, 5, 6, 7, 8, 9, A, B, C, D, E, F"
	 **************************************************************************************/
	private void write_tag() { 
		int WriteArea = mSpinWriteArea.getSelectedItemPosition(); //select write tag area
		Log.i("_WM_", "select write tag - area = " + WriteArea);
		String data = mSetWriteData.getText().toString();	//write data
		rfid.UHF_Write(mContext, WriteArea, data);
	}
	

	/****************************************************************************************
	 * 	_WM_RFID API:
	 * 
	 * 	public static enum TriggerMode {
	 *		Auto,
	 *		Single; 
	 *	}
	 *
	 * 	Trigger Mode:
	 * 		1. _WM_RFID.TriggerMode.Auto
	 * 		2. _WM_RFID.TriggerMode.Single
	 * 
	 * **************************************************************************************
	 * _WM_RFID API:
	 * 
	 * 	public static enum TriggerTime {
	 *		Sec_1,
	 *		Sec_2,
	 *		Sec_3,
	 *		Sec_4,
	 *		Sec_5,
	 *		Sec_6,
	 *		Sec_7,
	 *		Sec_8,
	 *		Sec_9;
	 *	}
	 *
	 * 	Trigger Time:
	 * 	 	1. _WM_RFID.TriggerTime.Sec_1 
	 *  		...
	 *  		...
	 *   	9. _WM_RFID.TriggerTime.Sec_9 
	 * 
	 *  Note: If trigger mode is selected "Auto", the trigger time will be ignore.
	 *  
	 **************************************************************************************/
	private void set_trigger_mode() { 
		int mode = mSpinTriggerMode.getSelectedItemPosition(); //select trigger mode
		int time = mSpinTriggerTime.getSelectedItemPosition(); //select trigger time
		Log.i("_WM_", "set_trigger_mode - mode = " + mode + " , " + "time = " + time);
		rfid.SetTriggerMode(mContext, _WM_RFID.TriggerMode.values()[mode], _WM_RFID.TriggerTime.values()[time]);
	}
	
	
}
